@@ -164,21 +164,22 @@ typedef enum {
 	OPTION_SHADOW_PRIMARY,
 	OPTION_TEAR_FREE,
 	OPTION_DELETE_DP12,
+	OPTION_VARIABLE_REFRESH,
 } AMDGPUOpts;
 
 static inline ScreenPtr
-amdgpu_master_screen(ScreenPtr screen)
+amdgpu_primary_screen(ScreenPtr screen)
 {
-	if (screen->current_master)
-		return screen->current_master;
+	if (screen->current_primary)
+		return screen->current_primary;
 
 	return screen;
 }
 
 static inline ScreenPtr
-amdgpu_dirty_master(PixmapDirtyUpdatePtr dirty)
+amdgpu_dirty_primary(PixmapDirtyUpdatePtr dirty)
 {
-	return amdgpu_master_screen(dirty->slave_dst->drawable.pScreen);
+	return amdgpu_primary_screen(dirty->secondary_dst->drawable.pScreen);
 }
 
 static inline DrawablePtr
@@ -239,12 +240,14 @@ struct amdgpu_device_priv {
 	Bool sprite_visible;
 };
 
+struct amdgpu_window_priv {
+	Bool variable_refresh;
+};
+
 extern DevScreenPrivateKeyRec amdgpu_device_private_key;
 
 typedef struct {
 	EntityInfoPtr pEnt;
-	struct pci_device *PciInfo;
-	int Chipset;
 	uint32_t family;
 	struct gbm_device *gbm;
 
@@ -264,13 +267,13 @@ typedef struct {
 	struct amdgpu_dri2 dri2;
 
 	/* accel */
-	PixmapPtr fbcon_pixmap;
 	int callback_event_type;
 	uint_fast32_t gpu_flushed;
 	uint_fast32_t gpu_synced;
 	Bool use_glamor;
 	Bool force_accel;
 	Bool shadow_primary;
+	Bool vrr_support;
 	int tear_free;
 
 	/* general */
@@ -281,19 +284,16 @@ typedef struct {
 	CreateScreenResourcesProcPtr CreateScreenResources;
 	CreateWindowProcPtr CreateWindow;
 	WindowExposuresProcPtr WindowExposures;
-	void (*SetCursor) (DeviceIntPtr pDev, ScreenPtr pScreen,
-			   CursorPtr pCursor, int x, int y);
-	void (*MoveCursor) (DeviceIntPtr pDev, ScreenPtr pScreen, int x, int y);
+	miPointerSpriteFuncPtr SpriteFuncs;
 
 	/* Number of SW cursors currently visible on this screen */
 	int sprites_visible;
 
-	Bool IsSecondary;
+	int instance_id;
 
 	Bool shadow_fb;
 	void *fb_shadow;
 	struct amdgpu_buffer *front_buffer;
-	struct amdgpu_buffer *cursor_buffer[32];
 
 	uint64_t vram_size;
 	uint64_t gart_size;
@@ -304,6 +304,7 @@ typedef struct {
 	int group_bytes;
 
 	/* kms pageflipping */
+	WindowPtr flip_window;
 	Bool allowPageFlip;
 
 	/* cursor size */
@@ -348,8 +349,9 @@ typedef struct {
 Bool amdgpu_dri3_screen_init(ScreenPtr screen);
 
 /* amdgpu_kms.c */
+Bool amdgpu_window_has_variable_refresh(WindowPtr win);
 Bool amdgpu_scanout_do_update(xf86CrtcPtr xf86_crtc, int scanout_id,
-			      PixmapPtr src_pix, BoxPtr extents);
+			      PixmapPtr src_pix, BoxRec extents);
 void AMDGPUWindowExposures_oneshot(WindowPtr pWin, RegionPtr pRegion
 #if XORG_VERSION_CURRENT < XORG_VERSION_NUMERIC(1,16,99,901,0)
 				   , RegionPtr pBSRegion
@@ -357,6 +359,7 @@ void AMDGPUWindowExposures_oneshot(WindowPtr pWin, RegionPtr pRegion
 				   );
 
 /* amdgpu_present.c */
+void amdgpu_present_set_screen_vrr(ScrnInfoPtr scrn, Bool vrr_enabled);
 Bool amdgpu_present_screen_init(ScreenPtr screen);
 
 /* amdgpu_sync.c */
